﻿using System;
namespace myBlazorApp.Components;

using System.Reflection.Metadata;
using Blazorise;
using Microsoft.AspNetCore.Components;
using myBlazorApp.Models;

public partial class InventoryItem
{
    [Parameter]
    public string Item { get; set; }

    [Parameter]
    public int Index { get; set; }

    [Parameter]
    public int Number { get; set; }

    [Parameter]
    public bool NoDrop { get; set; }

    [CascadingParameter]
    public MyInventory Parent { get; set; }

    internal void OnDragEnter()
    {
        if (NoDrop)
        {
            return;
        }
        Parent.Actions.Add(new InventoryAction { Action = "Drag Enter", ItemName = this.Item, Index = this.Index, Number = this.Number });
    }

    internal void OnDragLeave()
    {
        if (NoDrop)
        {
            return;
        }
        Parent.Actions.Add(new InventoryAction { Action = "Drag Leave", ItemName = this.Item, Index = this.Index, Number = this.Number });
    }

    internal void OnDrop()
    {
        if (NoDrop)
        {
            return;
        }
        if (Parent.CurrentDragItem != "null")
        {
            if(this.Item == Parent.CurrentDragItem)
            {
                this.Number = this.Number + Parent.CurrentDragNumber;
                Parent.CurrentInventoryItem.Number = 0;
                Parent.CurrentInventoryItem.Item = "null";
                Parent.ItemsInventory[Parent.CurrentInventoryItem.Index-1] = new InventoryListItem(Parent.CurrentInventoryItem.Item, Parent.CurrentInventoryItem.Index, Parent.CurrentInventoryItem.Number);
                Parent.Actions.Add(new InventoryAction { Action = "End", ItemName = Parent.CurrentInventoryItem.Item, Index = Parent.CurrentInventoryItem.Index, Number = Parent.CurrentInventoryItem.Number });
            }
            else
            {
                string tmpItem = this.Item;
                int tmpNumber = this.Number;
                Parent.ItemsInventory[Parent.CurrentDragIndex-1] = new InventoryListItem(tmpItem, Parent.CurrentDragIndex, tmpNumber);
                this.Item = Parent.CurrentDragItem;
                this.Number = Parent.CurrentDragNumber;
                Parent.CurrentInventoryItem.Item = tmpItem;
                Parent.CurrentInventoryItem.Number = tmpNumber;
            }
            
        }
        Parent.Actions.Add(new InventoryAction { Action = "Drop", ItemName = this.Item, Index = this.Index, Number = this.Number });
    }

    internal void OnDragEnd()
    {
        if(NoDrop || Parent.CurrentDragItem == "null")
        {
            return;
        }
        if (Parent.CurrentDragIndex != -1 && Parent.CurrentDragIndex != this.Index)
        {
            Parent.ItemsInventory[this.Index-1] = new InventoryListItem(Parent.CurrentDragItem, Parent.CurrentDragIndex, Parent.CurrentDragNumber);
            this.Item = Parent.CurrentDragItem;
            this.Number = Parent.CurrentDragNumber;
        }
        Parent.CurrentDragIndex = -1;
        Parent.CurrentDragItem = "null";
        Parent.CurrentDragNumber = 0;
        Parent.Actions.Add(new InventoryAction { Action = "End", ItemName = this.Item, Index = this.Index, Number = this.Number });

    }

    private void OnDragStart()
    {
        Parent.CurrentInventoryItem = this;
        Parent.CurrentDragIndex = this.Index;
        Parent.CurrentDragItem = this.Item;
        Parent.CurrentDragNumber = this.Number;
        this.Item = "null";
        this.Number = 0;
        Parent.Actions.Add(new InventoryAction { Action = "Drag Start", ItemName = this.Item, Index = this.Index, Number = this.Number});

    }
}

